%global pkgname semigroups

Name:           gap-pkg-%{pkgname}
Version:        2.6
Release:        1%{?dist}
Summary:        GAP methods for semigroups

License:        GPLv3+
URL:            http://www-groups.mcs.st-andrews.ac.uk/~jamesm/semigroups.php
Source0:        http://www-groups.mcs.st-andrews.ac.uk/~jamesm/semigroups/%{pkgname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  gap-pkg-genss
BuildRequires:  gap-pkg-grape
BuildRequires:  gap-pkg-io
BuildRequires:  gap-pkg-orb
BuildRequires:  gap-pkg-smallsemi

Requires:       gap-core
Requires:       gap-pkg-io
Requires:       gap-pkg-orb

Recommends:     gap-pkg-genss
Recommends:     gap-pkg-grape

%description
This is a GAP package containing methods for semigroups, monoids, and
inverse semigroups, principally of transformations, partial
permutations, bipartitions, subsemigroups of regular Rees 0-matrix
semigroups, free inverse semigroups, free bands, and semigroups of
matrices over finite fields.

Semigroups contains more efficient methods than those available in the
GAP library (and in many cases more efficient than any other software)
for creating semigroups, monoids, and inverse semigroup, calculating
their Green's structure, ideals, size, elements, group of units, small
generating sets, testing membership, finding the inverses of a regular
element, factorizing elements over the generators, and many more.  It is
also possible to test if a semigroup satisfies a particular property,
such as if it is regular, simple, inverse, completely regular, and a
variety of further properties.

There are methods for finding congruences of certain types of
semigroups, the normalizer of a semigroup in a permutation group, the
maximal subsemigroups of a finite semigroup, and smaller degree partial
permutation representations of inverse semigroups.  There are functions
for producing pictures of the Green's structure of a semigroup, and for
drawing bipartitions.

%prep
%setup -q -n %{pkgname}-%{version}

# Remove an archive file
rm .hg_archival.txt

# Fix end-of-line encoding
sed -i.orig 's/\r//' README.md
touch -r README.md.orig README.md
rm -f README.md.orig

%build
export LC_ALL=en_US.UTF-8

# Tell this package that gap-pkg-grape is compiled (because it is!)
sed -e 's/BindGlobal("IsGrapeCompiled",/& true);/' \
    -e '/dreadnautB/d' \
    -i.orig read.g
touch -r read.g.orig read.g
rm -f read.g.orig

sed -i.orig 's/Filename.*,"dreadnautB")<>fail/true/' tst/testinstall.tst
touch -r tst/testinstall.tst.orig tst/testinstall.tst
rm -f tst/testinstall.tst.orig

# Link to main GAP documentation
ln -s %{_gap_dir}/doc ../../doc
mkdir -p ../pkg
ln -s ../%{pkgname}-%{version} ../pkg
gap -l "$PWD/..;%{_gap_dir}" << EOF
LoadPackage( "semigroups" );
SemigroupsMakeDoc();
CopyHTMLStyleFiles( "doc" );
GAPDocManualLab( "semigroups" );
EOF
rm -fr ../../doc ../pkg

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname}-%{version} %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{GPL,LICENSE,VERSIONS,*.md}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilx,ind,log,orig,out,pnr,toc}

%check
export LC_ALL=en_US.UTF-8
cd tst
gap -l "%{_gap_dir};%{buildroot}%{_gap_dir}" << EOF 2>&1 | tee log
LoadPackage("semigroups");
ReadTest("testinstall.tst");
EOF
grep -Fvq fail log
rm -f log

%files
%doc CHANGELOG.md CONTRIBUTING.md README.md VERSIONS
%license GPL LICENSE
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Thu Oct 22 2015 Jerry James <loganjerry@gmail.com> - 2.6-1
- Initial RPM
